@@ -5,9 +5,10 @@ from traceback import format_exc
 from .errors import Error
 from .version import version
 from .utils import tryimport
+from .states import NormalState
 from .parser import parse, tokenize
 
-from .method import Method
+from .block import Block
 from .object import Object
 from .parser import Parser
 from .message import Message
@@ -24,57 +25,73 @@ from .types import System
 
 class State(object):
 
-    def __init__(self, args, opts, lobby):
+    def __init__(self, args, opts, root):
         super(State, self).__init__()
 
         self.args = args
         self.opts = opts
-        self.lobby = lobby
+        self.root = root
 
         if self.args is None:
             self.args = []
 
-        self.reset()
+        self._value = None
+        self._state = NormalState()
+
+    @property
+    def value(self):
+        return self._value
+
+    @value.setter
+    def value(self, value):
+        self._value = value
+
+    @property
+    def state(self):
+        return self._state
+
+    @property
+    def stop(self):
+        return self.state.isBreak or self.state.isContinue or self.state.isReturn
 
     def reset(self):
-        self.returnValue = None
-        self.isContinue = False
-        self.isReturn = False
-        self.isBreak = False
+        self._state = NormalState()
 
-    def stop(self):
-        return self.isBreak or self.isReturn
+    def set(self, state):
+        self._state = state
 
     def create_objects(self):
-        lobby = self.lobby
+        root = self.root
 
         object = Object(methods=True)
 
-        lobby["Lobby"] = lobby
-        lobby["Object"] = object
+        root["Root"] = root
+        root["Object"] = object
 
-        lobby.parent = object
+        root.parent = object
 
-        lobby["Boolean"] = Boolean()
-        lobby["Number"] = Number()
-        lobby["String"] = String()
-        lobby["List"] = List()
+        root["Boolean"] = Boolean()
+        root["Number"] = Number()
+        root["String"] = String()
+        root["List"] = List()
 
-        lobby["None"] = Boolean(None)
-        lobby["True"] = Boolean(True)
-        lobby["False"] = Boolean(False)
+        root["None"] = Boolean(None)
+        root["True"] = Boolean(True)
+        root["False"] = Boolean(False)
 
-        lobby["Parser"] = Parser()
-        lobby["Message"] = Message("")
-        lobby["Continuation"] = Continuation()
-        lobby["Method"] = Method(None, Message(""), [], {})
+        root["Parser"] = Parser()
+        root["Message"] = Message("")
+        root["Continuation"] = Continuation()
+        root["Block"] = Block(None, [], {})
 
-        lobby["File"] = File()
-        lobby["Range"] = Range()
-        lobby["System"] = System()
+        root["File"] = File()
+        root["Range"] = Range()
+        root["System"] = System()
+
+        root["_"] = root["None"]
 
     def find(self, name):
-        return self.lobby.attrs[name]
+        return self.root.attrs[name]
 
     def eval(self, code, receiver=None, context=None, reraise=False):
         message = None
@@ -87,7 +104,7 @@ class State(object):
             else:
                 message = parse(tokenize(code))
 
-            return message.eval(self.lobby if receiver is None else receiver, self.lobby if context is None else context, message)
+            return message.eval(self.root if receiver is None else receiver, self.root if context is None else context, message)
         except Error as e:
             type = e.__class__.__name__
             underline = "-" * (len(type) + 1)
